@@ -13,6 +13,9 @@ class TestCollection(TestCase):
     def getTestObj(self):
         return skos.Collection('uri', 'title', 'description')
 
+    def testInheritance(self):
+        super(TestCollection, self).doTestInheritance()
+
     def testEqual(self):
         collection = self.getTestObj()
         self.assertEqual(self.obj, collection)
@@ -42,5 +45,5 @@ class TestCollection(TestCase):
         self.assertEqual(len(collection.members), 2)
 
 if __name__ == '__main__':
-    import unittest
+    from test import unittest
     unittest.main(verbosity=2)
