@@ -13,6 +13,9 @@ class TestConceptScheme(TestCase):
     def getTestObj(self):
         return skos.ConceptScheme('uri', 'title', 'description')
 
+    def testInheritance(self):
+        super(TestConceptScheme, self).doTestInheritance()
+
     def testEqual(self):
         scheme = self.getTestObj()
         self.assertEqual(self.obj, scheme)
@@ -42,5 +45,5 @@ class TestConceptScheme(TestCase):
         self.assertEqual(len(scheme.concepts), 2)
 
 if __name__ == '__main__':
-    import unittest
+    from test import unittest
     unittest.main(verbosity=2)
